==> tine20-allinone_2020.08.8.tar.bz2: Crm/js/Crm-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Mọi khởi đầu"

, "Default Lead List"
: "Danh sách đầu mối mặc định"

, "The default list for new leads"
: "Danh sách mặc định cho đầu mối mới"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Mức độ hoạt động bạn muốn được thông báo"

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Thường dùng mặc định"

, "The default favorite which is loaded on crm startup"
: "Thường dùng mặc định được nạp khi quản lý quan hệ khách hàng được nạp"

, "New Lead"
: "Đầu mối mới"

, "Tags"
: "Thẻ"

, "Lead name"
: "Tên đầu mối"

, "Responsible"
: "Trách nhiệm"

, "Partner"
: "Đôi tác"

, "Customer"
: "Khách hàng"

, "Leadstate"
: "Trạng thái đầu mối"

, "Leadtype"
: "Loại đầu mối"

, "Leadsource"
: "Nguồn đầu mối"

, "Probability"
: "Có khả năng"

, "Turnover"
: "Doanh số"

, "Estimated end"
: "Dự kiến thời gian kết thúc"

, "Probable Turnover"
: "Có thể bỏ qua"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Liên hệ"

, "CRM Role"
: "Vai trò quan hệ khách hàng"

, "Tasks"
: "Công việc"

, "No Tasks to display"
: "Chưa có việc gì"

, "Summary"
: "Tóm tắt"

, "Add a task..."
: "Thêm 1 việc..."

, "Due Date"
: "Ngày đến hạn"

, "Priority"
: "Độ quan trọng"

, "Percent"
: "Phần trăm"

, "Status"
: "Trạng thái"

, "Organizer"
: ""

, "Add new {0}"
: "Thêm mới {0}"

, "Unlink {0}"
: "Ngừng liên kết {0}"

, "Unlink selected {0}"
: "Ngừng liên kết phần chọn {0}"

, "Edit {0}"
: "Sửa {0}"

, "Edit selected {0}"
: "Sửa phần chọn {0}"

, "Please choose the Lead to add the contacts to"
: "Xin chọn đầu mối để thêm liên lạc"

, "Please select the attenders' role"
: "Chọn vai trò người tham gia"

, "Lead, Leads"
: [
  "one: Đầu mối\nother: Đầu mối khác"

]
, "Select Lead"
: "Chọn đầu mối"

, "Role"
: "Vai trò"

, "Select Role"
: "Chọn vai trò"

, "Adding {0} contacts to lead"
: "Thêm {0} liên lạc vào đầu mối"

, "Phone"
: "Điện thoại"

, "Mobile"
: "Điện thoại"

, "Fax"
: "Fax"

, "E-Mail"
: "Email"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Bắt đầu"

, "Change type to Customer"
: "Đổi loại khách hàng"

, "Change type to Responsible"
: "Thay đổi loại trách nhiệm"

, "Change type to Partner"
: "Thay đổi loại đối tác"

, "Change contact type"
: "Thay đổi kiểu liên lạc"

, "Search for Contacts to add ..."
: "Tìm kiếm liên lạc để thêm..."

, "Name"
: "Tên"

, "Address"
: "Địa chỉ"

, "Data"
: "Dữ liệu"

, "Cellphone"
: "Số cầm tay"

, "End"
: "Kết thúc"

, "You do not have the run right for the Tasks application or it is not activated."
: "Bạn không có quyền chạy ứng dụng Công việc hoặc nó chưa được kích hoạt"

, "Products"
: "Sản phẩm"

, "You do not have the run right for the Sales application or it is not activated."
: "Bạn không có quyền chạy ứng dụng Bán hàng hoặc nó chưa được kích hoạt"

, "Enter lead name"
: ""

, "Expected turnover"
: "Doanh số mong đợi"

, "Description"
: "Mô tả"

, "Enter description"
: "Nhập mô tả"

, "lead list, lead lists"
: [
  "one: danh sách lãnh đạo\nother: danh sách lãnh đạo"

]
, "lead lists"
: "danh sách lãnh đạo"

, "Quick Search"
: "Tìm nhanh"

, "Last Modified Time"
: "Thời gian sửa lần cuối"

, "Last Modified By"
: "Sửa lần cuối bởi"

, "Creation Time"
: "Thời gian tạo"

, "Created By"
: "Tạo bởi"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Sản phẩm"

, "Price"
: "Giá"

, "Quantity"
: "Số lượng"

, "Search for Products to add ..."
: "Tìm sản phẩm để thêm..."

, "All leads I have read grants for"
: "Mọi đầu mối tôi đã đọc quyền"

, "Last modified by me"
: "Sửa lần cuối bởi tôi"

, "All leads that I have last modified"
: "Mọi đầu mối tôi đã sửa"

, "My leads"
: "Đầu mối của tôi"

, "All leads that I am responsible for"
: "Mọi đầu mối tôi chịu trách nhiệm"

, "Leads with overdue tasks"
: "Đầu mối với việc quá hạn"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "mở"

, "contacted"
: "đã liên lạc"

, "waiting for feedback"
: "đang đợi trả lời"

, "quote sent"
: "báo giá đã gửi"

, "accepted"
: "đã chấp nhận"

, "lost"
: "mất"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Đại lý"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Trạng thái"

, "Source"
: "Nguồn"

, "Scheduled end"
: "Kết thúc theo lịch"

, "Folder"
: "Thư mục"

, "Updated by"
: "Cập nhật bởi"

, "Updated Fields:"
: "Trường được cập nhật"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Đầu mối %s đã được thay đổi"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Đầu mối %s đã được tạo"

, "Task"
: "Công việc"

, "Lead Data"
: "Dữ liệu đầu mối"

, "End Scheduled"
: "Lịch kết thúc"

, "Contacts"
: "Liên lạc"

, "Telephone"
: "Điện thoại"

, "Email"
: "Email"

, "low"
: "thấp"

, "normal"
: "thường"

, "high"
: "cao"

, "urgent"
: "khẩn cấp"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "Quản lý thư mục đầu mối chia sẻ"

, "Create new shared lead folders"
: "Tạo thư mục đầu mối chia sẻ mới"

, "manage shared leads favorites"
: "quản lý đầu mối chia sẻ thường dùng"

, "Create or update shared leads favorites"
: "Tạo hoặc cập nhật đầu mối chia sẻ thường dùng"




, "Lead"
: "one: Đầu mối\nother: Đầu mối khác"

, "lead list"
: "one: danh sách lãnh đạo\nother: danh sách lãnh đạo"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Khách hàng"

, "Partner"
: "Đôi tác"

, "Phone"
: "Điện thoại"

, "Mobile"
: "Điện thoại"

, "Fax"
: "Fax"

, "E-Mail"
: "Email"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Trạng thái"

, "Start"
: "Bắt đầu"

, "Estimated end"
: "Dự kiến thời gian kết thúc"

, "Leadtype"
: "Loại đầu mối"

, "Leadsource"
: "Nguồn đầu mối"

, "Tags"
: "Thẻ"

, "Lead name"
: "Tên đầu mối"

, "Responsible"
: "Trách nhiệm"

, "Leadstate"
: "Trạng thái đầu mối"

, "Probability"
: "Có khả năng"

, "Turnover"
: "Doanh số"

, "End"
: "Kết thúc"

, "Probable Turnover"
: "Có thể bỏ qua"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Add new {0}"
: "Thêm mới {0}"

, "Unlink {0}"
: "Ngừng liên kết {0}"

, "Unlink selected {0}"
: "Ngừng liên kết phần chọn {0}"

, "Edit {0}"
: "Sửa {0}"

, "Edit selected {0}"
: "Sửa phần chọn {0}"

, "New Lead"
: "Đầu mối mới"

, "Products"
: "Sản phẩm"

, "Product"
: "Sản phẩm"

, "Description"
: "Mô tả"

, "Price"
: "Giá"

, "Quantity"
: "Số lượng"

, "Search for Products to add ..."
: "Tìm sản phẩm để thêm..."

, "1"
: ""

, "Notifications are disabled"
: ""

, "Send Notification?"
: ""

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "Tasks"
: "Công việc"

, "You do not have the run right for the Tasks application or it is not activated."
: "Bạn không có quyền chạy ứng dụng Công việc hoặc nó chưa được kích hoạt"

, "You do not have the run right for the Sales application or it is not activated."
: "Bạn không có quyền chạy ứng dụng Bán hàng hoặc nó chưa được kích hoạt"

, "Lead, Leads"
: [
  "one: Đầu mối\nother: Đầu mối khác"

]
, "Enter lead name"
: ""

, "Expected turnover"
: "Doanh số mong đợi"

, "Enter description"
: "Nhập mô tả"

, "lead list, lead lists"
: [
  "one: danh sách lãnh đạo\nother: danh sách lãnh đạo"

]
, "lead lists"
: "danh sách lãnh đạo"

, "Quick Search"
: "Tìm nhanh"

, "Last Modified Time"
: "Thời gian sửa lần cuối"

, "Last Modified By"
: "Sửa lần cuối bởi"

, "Creation Time"
: "Thời gian tạo"

, "Created By"
: "Tạo bởi"

, "X Lead"
: ""

, "read-only"
: ""

, "Archived"
: ""

, "Contact"
: "Liên hệ"

, "CRM Role"
: "Vai trò quan hệ khách hàng"

, "Change type to Customer"
: "Đổi loại khách hàng"

, "Change type to Responsible"
: "Thay đổi loại trách nhiệm"

, "Change type to Partner"
: "Thay đổi loại đối tác"

, "Change contact type"
: "Thay đổi kiểu liên lạc"

, "Search for Contacts to add ..."
: "Tìm kiếm liên lạc để thêm..."

, "Name"
: "Tên"

, "Address"
: "Địa chỉ"

, "Data"
: "Dữ liệu"

, "Cellphone"
: "Số cầm tay"

, "Role"
: "Vai trò"

, "Please choose the Lead to add the contacts to"
: "Xin chọn đầu mối để thêm liên lạc"

, "Please select the attenders' role"
: "Chọn vai trò người tham gia"

, "Select Lead"
: "Chọn đầu mối"

, "Select Role"
: "Chọn vai trò"

, "Adding {0} contacts to lead"
: "Thêm {0} liên lạc vào đầu mối"

, "No Tasks to display"
: "Chưa có việc gì"

, "Summary"
: "Tóm tắt"

, "Add a task..."
: "Thêm 1 việc..."

, "Due Date"
: "Ngày đến hạn"

, "Priority"
: "Độ quan trọng"

, "Percent"
: "Phần trăm"

, "Organizer"
: ""

, "All leads"
: "Mọi khởi đầu"

, "Default Lead List"
: "Danh sách đầu mối mặc định"

, "The default list for new leads"
: "Danh sách mặc định cho đầu mối mới"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Mức độ hoạt động bạn muốn được thông báo"

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Default Favorite"
: "Thường dùng mặc định"

, "The default favorite which is loaded on crm startup"
: "Thường dùng mặc định được nạp khi quản lý quan hệ khách hàng được nạp"

, "controls sending notification of Leads"
: ""

, "send notification)description"
: ""

, "send notification to all access container"
: ""

, "send notification to responsible"
: ""

, "send notification to responsible)description"
: ""

, "send notification to customer"
: ""

, "send notification to partner"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "mở"

, "contacted"
: "đã liên lạc"

, "waiting for feedback"
: "đang đợi trả lời"

, "quote sent"
: "báo giá đã gửi"

, "accepted"
: "đã chấp nhận"

, "lost"
: "mất"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Đại lý"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Lead Notification Confirmation"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead Data"
: "Dữ liệu đầu mối"

, "End Scheduled"
: "Lịch kết thúc"

, "Contacts"
: "Liên lạc"

, "Telephone"
: "Điện thoại"

, "Email"
: "Email"

, "low"
: "thấp"

, "normal"
: "thường"

, "high"
: "cao"

, "urgent"
: "khẩn cấp"

, "CSV all data"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "GENDER_Lead"
: ""

, "Show Closed"
: ""

, "Task"
: "Công việc"

, "State"
: "Trạng thái"

, "Source"
: "Nguồn"

, "Scheduled end"
: "Kết thúc theo lịch"

, "Folder"
: "Thư mục"

, "Updated by"
: "Cập nhật bởi"

, "Updated Fields:"
: "Trường được cập nhật"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Đầu mối %s đã được thay đổi"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Đầu mối %s đã được tạo"

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: ""

, "All leads I have read grants for"
: "Mọi đầu mối tôi đã đọc quyền"

, "Last modified by me"
: "Sửa lần cuối bởi tôi"

, "All leads that I have last modified"
: "Mọi đầu mối tôi đã sửa"

, "My leads"
: "Đầu mối của tôi"

, "All leads that I am responsible for"
: "Mọi đầu mối tôi chịu trách nhiệm"

, "Leads with overdue tasks"
: "Đầu mối với việc quá hạn"

, "manage shared lead folders"
: "Quản lý thư mục đầu mối chia sẻ"

, "Create new shared lead folders"
: "Tạo thư mục đầu mối chia sẻ mới"

, "manage shared leads favorites"
: "quản lý đầu mối chia sẻ thường dùng"

, "Create or update shared leads favorites"
: "Tạo hoặc cập nhật đầu mối chia sẻ thường dùng"




, "Lead"
: "one: Đầu mối\nother: Đầu mối khác"

, "lead list"
: "one: danh sách lãnh đạo\nother: danh sách lãnh đạo"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
